from botty_core import env

BOT_TOKEN = env.get("BOT_TOKEN")
